"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
exports.__esModule = true;
var get_mediatype_examples_1 = __importDefault(require("../lib/get-mediatype-examples"));
/**
 * Retrieve a collection of request body examples, keyed by their media type.
 *
 * @param operation Operation to retrieve requestBody examples for.
 */
function getRequestBodyExamples(operation) {
    // `requestBody` will never have `$ref` pointers here so we need to work around the type that we
    // have from `RMOAS.OperationObject`.
    var requestBody = operation.requestBody;
    if (!requestBody || !requestBody.content) {
        return [];
    }
    return Object.keys(requestBody.content || {})
        .map(function (mediaType) {
        var mediaTypeObject = requestBody.content[mediaType];
        var examples = (0, get_mediatype_examples_1["default"])(mediaType, mediaTypeObject, {
            includeReadOnly: false,
            includeWriteOnly: true
        });
        if (!examples.length) {
            return false;
        }
        return {
            mediaType: mediaType,
            examples: examples
        };
    })
        .filter(Boolean);
}
exports["default"] = getRequestBodyExamples;
